todynapcnn
==========

This module describes the ``DynapcnnCompatibleNetwork`` class that is used to transform a spiking neural network into a network that is compatible with dynapcnn.

.. automodule:: sinabs.backend.dynapcnn.todynapcnn
    :members:
